
# Enum: EmploymentEventType




URI: [ks:EmploymentEventType](https://w3id.org/linkml/tests/kitchen_sink/EmploymentEventType)


## Other properties

|  |  |  |
| --- | --- | --- |

## Permissible Values

| Text | Description | Meaning | Other Information |
| :--- | :---: | :---: | ---: |
| HIRE |  | bizcodes:001 |  |
| FIRE |  | bizcodes:002 |  |
| PROMOTION |  | bizcodes:003 |  |
| TRANSFER |  | bizcodes:004 |  |

